cwctl.py
changeset 3629 559cad62c786
parent 3589 a5432f99f2d9
parent 3619 af81a4f7053e
child 3674 387d51af966d
--- a/cwctl.py	Wed Oct 07 12:38:30 2009 +0200
+++ b/cwctl.py	Fri Oct 09 16:39:26 2009 +0200
@@ -71,7 +71,10 @@
     def ordered_instances(self):
         """return instances in the order in which they should be started,
         considering $REGISTRY_DIR/startorder file if it exists (useful when
-        some instances depends on another as external source
+        some instances depends on another as external source).
+
+        Instance used by another one should appears first in the file (one
+        instance per line)
         """
         regdir = cwcfg.registry_dir()
         _allinstances = list_instances(regdir)